/*
    Valtra Tractors
    Copyright 2004 Martin Storsj

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Martin Storsj
    martin@martin.st
*/

#ifndef __DIALOG_H
#define __DIALOG_H

#include <SDL.h>
#include <SDL_ttf.h>
#include <vector>
#include <utility>
#include "sprites.h"
#include "point.h"
#include "button.h"
#include "game.h"

using std::vector;
using std::pair;


class TextArea {
private:
	TTF_Font *font;
	vector<const char *> strings;
	vector<int> ids;
	IPoint pos;
	bool centered;
	SDL_Color color;
	const char *strcopy(const char *text);
public:
	TextArea(TTF_Font *font, const char *text, int width, IPoint pos, SDL_Color color, bool centered = false);
	~TextArea();
	void setPos(IPoint pos);
	void getIds(SpriteEngine *se);
	void addSprites(SpriteEngine *se);
	void updateSprites(SpriteEngine *se);
	void doneDrawing(SpriteEngine *se);
};


enum DialogType { QUIT, NEWGAME, PLAYERS, CHOOSE, RESULT };

const int tractors[] = { 2, 0, 1, 3 };

class Dialog {
private:
	DialogType type;
	SpriteEngine se;
	SDL_Surface *surf;
	SDL_Surface *dialogBkg;
//	SDL_Surface *buttonSurf[3], *arrow[3];
	vector<Button*> buttons;
	vector<TextArea*> texts;
	TTF_Font *font;
	bool initTTF;
	GameWrapper *wrapper;
	TextArea *text;
	int buttonover, buttondown;
	bool quit;
	int result;

	int data;

	SDL_Surface *tractor[4];
	int current;
	vector<pair<int,int> > stats;
	

	int getButton(int x, int y);
	void action(int button);
	bool isClickable(int button);
public:
	Dialog(DialogType type, int data = 0);
	~Dialog();
	void update();
	SDL_Surface *getSurface();
	void getRects(vector<SDL_Rect> &list);
	void handleEvent(SDL_Event &event);
	void setWrapper(GameWrapper *wrapper);
	bool finished();
	int getResult();
};


#endif
